@@ -5,3 +5,6 @@ def test_use_provider(accounts, networks):
 
         assert not receipt.failed
         assert receipt.value == 100
+
+        # Transactions in Optimism are always static-fee type (0).
+        assert receipt.type == 0
